# **cosmolib**

_A lightweight Python library for handling cosmology data formats and creating publication-quality plots._
Designed for **clarity**, **composability**, and **seamless data format integration** into scientific cosmological softwares.

---

## 📘 Table of Contents

- [Installation](#installation)
- [License](#license)

---

## ⚙️ Installation

**From PyPI (recommended):**

```bash
pip install cosmolib
```

**From source (for developers and contributors):**

```bash
git clone https://github.com/astro-ph/cosmolib.git
cd cosmolib
pip install -e .
```

## 📄 License

cosmolib is released under the MIT License.
You are free to use, modify, and distribute it under the terms of this license.
